@@ -32,7 +32,7 @@ class IncludeDirectivesPPCallback : public clang::PPCallbacks {
   // Struct helping the detection of header guards in the various callbacks
   struct GuardDetection {
     GuardDetection(FileID FID)
-      : FID(FID), Count(0), TheMacro(0), CountAtEndif(0) {}
+      : FID(FID), Count(0), TheMacro(nullptr), CountAtEndif(0) {}
 
     FileID FID;
     // count for relevant preprocessor directives
@@ -58,7 +58,8 @@ class IncludeDirectivesPPCallback : public clang::PPCallbacks {
   };
 
 public:
-  IncludeDirectivesPPCallback(IncludeDirectives *Self) : Self(Self), Guard(0) {}
+  IncludeDirectivesPPCallback(IncludeDirectives *Self)
+      : Self(Self), Guard(nullptr) {}
 
 private:
   virtual ~IncludeDirectivesPPCallback() {}
@@ -66,7 +67,7 @@ private:
                           StringRef FileName, bool IsAngled,
                           CharSourceRange FilenameRange, const FileEntry *File,
                           StringRef SearchPath, StringRef RelativePath,
-                          const Module *Imported) LLVM_OVERRIDE {
+                          const Module *Imported) override {
     SourceManager &SM = Self->Sources;
     const FileEntry *FE = SM.getFileEntryForID(SM.getFileID(HashLoc));
     assert(FE && "Valid file expected.");
@@ -79,7 +80,7 @@ private:
   // Keep track of the current file in the stack
   virtual void FileChanged(SourceLocation Loc, FileChangeReason Reason,
                            SrcMgr::CharacteristicKind FileType,
-                           FileID PrevFID) {
+                           FileID PrevFID) override {
     SourceManager &SM = Self->Sources;
     switch (Reason) {
     case EnterFile:
@@ -142,13 +143,13 @@ private:
   }
 
   virtual void Ifndef(SourceLocation Loc, const Token &MacroNameTok,
-                      const MacroDirective *MD) {
+                      const MacroDirective *MD) override {
     Guard->Count++;
 
     // If this #ifndef is the top-most directive and the symbol isn't defined
     // store those information in the guard detection, the next step will be to
     // check for the define.
-    if (Guard->Count == 1 && MD == 0) {
+    if (Guard->Count == 1 && MD == nullptr) {
       IdentifierInfo *MII = MacroNameTok.getIdentifierInfo();
 
       if (MII->hasMacroDefinition())
@@ -159,13 +160,13 @@ private:
   }
 
   virtual void MacroDefined(const Token &MacroNameTok,
-                            const MacroDirective *MD) {
+                            const MacroDirective *MD) override {
     Guard->Count++;
 
     // If this #define is the second directive of the file and the symbol
     // defined is the same as the one checked in the #ifndef then store the
     // information about this define.
-    if (Guard->Count == 2 && Guard->TheMacro != 0) {
+    if (Guard->Count == 2 && Guard->TheMacro != nullptr) {
       IdentifierInfo *MII = MacroNameTok.getIdentifierInfo();
 
       // macro unrelated to the ifndef, doesn't look like a proper header guard
@@ -176,7 +177,7 @@ private:
     }
   }
 
-  virtual void Endif(SourceLocation Loc, SourceLocation IfLoc) {
+  virtual void Endif(SourceLocation Loc, SourceLocation IfLoc) override {
     Guard->Count++;
 
     // If it's the #endif corresponding to the top-most #ifndef
@@ -195,23 +196,32 @@ private:
   }
 
   virtual void MacroExpands(const Token &, const MacroDirective *, SourceRange,
-                            const MacroArgs *) {
+                            const MacroArgs *) override {
     Guard->Count++;
   }
-  virtual void MacroUndefined(const Token &, const MacroDirective *) {
+  virtual void MacroUndefined(const Token &,
+                              const MacroDirective *) override {
     Guard->Count++;
   }
-  virtual void Defined(const Token &, const MacroDirective *, SourceRange) {
+  virtual void Defined(const Token &, const MacroDirective *,
+                       SourceRange) override {
     Guard->Count++;
   }
-  virtual void If(SourceLocation, SourceRange, bool) { Guard->Count++; }
-  virtual void Elif(SourceLocation, SourceRange, bool, SourceLocation) {
+  virtual void If(SourceLocation, SourceRange,
+                  ConditionValueKind) override {
     Guard->Count++;
   }
-  virtual void Ifdef(SourceLocation, const Token &, const MacroDirective *) {
+  virtual void Elif(SourceLocation, SourceRange, ConditionValueKind,
+                    SourceLocation) override {
+    Guard->Count++;
+  }
+  virtual void Ifdef(SourceLocation, const Token &,
+                     const MacroDirective *) override {
+    Guard->Count++;
+  }
+  virtual void Else(SourceLocation, SourceLocation) override {
     Guard->Count++;
   }
-  virtual void Else(SourceLocation, SourceLocation) { Guard->Count++; }
 
   IncludeDirectives *Self;
   // keep track of the guard info through the include stack
@@ -354,7 +364,7 @@ Replacement IncludeDirectives::addAngledInclude(const clang::FileEntry *File,
     return Replacement();
 
   unsigned Offset, NLFlags;
-  llvm::tie(Offset, NLFlags) = angledIncludeInsertionOffset(FID);
+  std::tie(Offset, NLFlags) = angledIncludeInsertionOffset(FID);
 
   StringRef EOL = guessEOL(Sources, FID);
   llvm::SmallString<32> InsertionText;
