@@ -12,36 +12,29 @@
 //===----------------------------------------------------------------------===//
 
 #include "ClangTidyModule.h"
-#include "llvm/Support/Regex.h"
 
 namespace clang {
 namespace tidy {
 
-CheckFactoryBase::~CheckFactoryBase() {}
-
 ClangTidyCheckFactories::~ClangTidyCheckFactories() {
-  for (std::map<std::string, CheckFactoryBase *>::iterator
-           I = Factories.begin(),
-           E = Factories.end();
-       I != E; ++I) {
-    delete I->second;
-  }
+  for (const auto &Factory : Factories)
+    delete Factory.second;
 }
+
 void ClangTidyCheckFactories::addCheckFactory(StringRef Name,
                                               CheckFactoryBase *Factory) {
-
   Factories[Name] = Factory;
 }
 
 void ClangTidyCheckFactories::createChecks(
-    StringRef CheckRegexString, SmallVectorImpl<ClangTidyCheck *> &Checks) {
-  llvm::Regex CheckRegex(CheckRegexString);
-  for (std::map<std::string, CheckFactoryBase *>::iterator
-           I = Factories.begin(),
-           E = Factories.end();
-       I != E; ++I) {
-    if (CheckRegex.match(I->first))
-      Checks.push_back(I->second->createCheck());
+    ChecksFilter &Filter,
+    std::vector<std::unique_ptr<ClangTidyCheck>> &Checks) {
+  for (const auto &Factory : Factories) {
+    if (Filter.isCheckEnabled(Factory.first)) {
+      ClangTidyCheck *Check = Factory.second->createCheck();
+      Check->setName(Factory.first);
+      Checks.emplace_back(Check);
+    }
   }
 }
 
