@@ -142,6 +142,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+#include "Modularize.h"
+#include "PreprocessorTracker.h"
 #include "clang/AST/ASTConsumer.h"
 #include "clang/AST/ASTContext.h"
 #include "clang/AST/RecursiveASTVisitor.h"
@@ -152,8 +154,6 @@
 #include "clang/Lex/Preprocessor.h"
 #include "clang/Tooling/CompilationDatabase.h"
 #include "clang/Tooling/Tooling.h"
-#include "llvm/ADT/OwningPtr.h"
-#include "llvm/Config/config.h"
 #include "llvm/Option/Arg.h"
 #include "llvm/Option/ArgList.h"
 #include "llvm/Option/OptTable.h"
@@ -167,8 +167,6 @@
 #include <iterator>
 #include <string>
 #include <vector>
-#include "Modularize.h"
-#include "PreprocessorTracker.h"
 
 using namespace clang;
 using namespace clang::driver;
@@ -217,9 +215,10 @@ std::string CommandLine;
 
 // Read the header list file and collect the header file names and
 // optional dependencies.
-error_code getHeaderFileNames(SmallVectorImpl<std::string> &HeaderFileNames,
-                              DependencyMap &Dependencies,
-                              StringRef ListFileName, StringRef HeaderPrefix) {
+std::error_code
+getHeaderFileNames(SmallVectorImpl<std::string> &HeaderFileNames,
+                   DependencyMap &Dependencies, StringRef ListFileName,
+                   StringRef HeaderPrefix) {
   // By default, use the path component of the list file name.
   SmallString<256> HeaderDirectory(ListFileName);
   sys::path::remove_filename(HeaderDirectory);
@@ -231,14 +230,14 @@ error_code getHeaderFileNames(SmallVectorImpl<std::string> &HeaderFileNames,
     HeaderDirectory = HeaderPrefix;
 
   // Read the header list file into a buffer.
-  OwningPtr<MemoryBuffer> listBuffer;
-  if (error_code ec = MemoryBuffer::getFile(ListFileName, listBuffer)) {
-    return ec;
-  }
+  ErrorOr<std::unique_ptr<MemoryBuffer>> listBuffer =
+      MemoryBuffer::getFile(ListFileName);
+  if (std::error_code EC = listBuffer.getError())
+    return EC;
 
   // Parse the header list into strings.
   SmallVector<StringRef, 32> Strings;
-  listBuffer->getBuffer().split(Strings, "\n", -1, false);
+  listBuffer.get()->getBuffer().split(Strings, "\n", -1, false);
 
   // Collect the header file names from the string list.
   for (SmallVectorImpl<StringRef>::iterator I = Strings.begin(),
@@ -285,12 +284,12 @@ error_code getHeaderFileNames(SmallVectorImpl<std::string> &HeaderFileNames,
     Dependencies[HeaderFileName.str()] = Dependents;
   }
 
-  return error_code::success();
+  return std::error_code();
 }
 
 // Helper function for finding the input file in an arguments list.
 std::string findInputFile(const CommandLineArguments &CLArgs) {
-  OwningPtr<OptTable> Opts(createDriverOptTable());
+  std::unique_ptr<OptTable> Opts(createDriverOptTable());
   const unsigned IncludedFlagsBitmask = options::CC1Option;
   unsigned MissingArgIndex, MissingArgCount;
   SmallVector<const char *, 256> Argv;
@@ -298,7 +297,7 @@ std::string findInputFile(const CommandLineArguments &CLArgs) {
                                             E = CLArgs.end();
        I != E; ++I)
     Argv.push_back(I->c_str());
-  OwningPtr<InputArgList> Args(
+  std::unique_ptr<InputArgList> Args(
       Opts->ParseArgs(Argv.data(), Argv.data() + Argv.size(), MissingArgIndex,
                       MissingArgCount, IncludedFlagsBitmask));
   std::vector<std::string> Inputs = Args->getAllArgValues(OPT_INPUT);
@@ -355,7 +354,7 @@ struct Location {
     Column = SM.getColumnNumber(Decomposed.first, Decomposed.second);
   }
 
-  operator bool() const { return File != 0; }
+  operator bool() const { return File != nullptr; }
 
   friend bool operator==(const Location &X, const Location &Y) {
     return X.File == Y.File && X.Line == Y.Line && X.Column == Y.Column;
@@ -523,7 +522,7 @@ public:
     return true;
   }
   bool TraverseConstructorInitializer(CXXCtorInitializer *Init) { return true; }
-  bool TraverseLambdaCapture(LambdaExpr::Capture C) { return true; }
+  bool TraverseLambdaCapture(LambdaCapture C) { return true; }
 
   // Check 'extern "*" {}' block for #include directives.
   bool VisitLinkageSpecDecl(LinkageSpecDecl *D) {
@@ -707,15 +706,15 @@ int main(int Argc, const char **Argv) {
   // Get header file names and dependencies.
   SmallVector<std::string, 32> Headers;
   DependencyMap Dependencies;
-  if (error_code EC = getHeaderFileNames(Headers, Dependencies, ListFileName,
-                                         HeaderPrefix)) {
+  if (std::error_code EC = getHeaderFileNames(Headers, Dependencies,
+                                              ListFileName, HeaderPrefix)) {
     errs() << Argv[0] << ": error: Unable to get header list '" << ListFileName
            << "': " << EC.message() << '\n';
     return 1;
   }
 
   // If we are in assistant mode, output the module map and quit.
-  if (ModuleMapPath[0]) {
+  if (ModuleMapPath.length() != 0) {
     if (!createModuleMap(ModuleMapPath, Headers, Dependencies, HeaderPrefix,
                          RootModule))
       return 1; // Failed.
@@ -725,12 +724,12 @@ int main(int Argc, const char **Argv) {
   // Create the compilation database.
   SmallString<256> PathBuf;
   sys::fs::current_path(PathBuf);
-  OwningPtr<CompilationDatabase> Compilations;
+  std::unique_ptr<CompilationDatabase> Compilations;
   Compilations.reset(
       new FixedCompilationDatabase(Twine(PathBuf), CC1Arguments));
 
   // Create preprocessor tracker, to watch for macro and conditional problems.
-  OwningPtr<PreprocessorTracker> PPTracker(PreprocessorTracker::create());
+  std::unique_ptr<PreprocessorTracker> PPTracker(PreprocessorTracker::create());
 
   // Parse all of the headers, detecting duplicates.
   EntityMap Entities;
@@ -771,7 +770,7 @@ int main(int Argc, const char **Argv) {
     for (EntryBinArray::iterator DI = EntryBins.begin(), DE = EntryBins.end();
          DI != DE; ++DI, ++KindIndex) {
       int ECount = DI->size();
-      // If only 1 occurrence, skip;
+      // If only 1 occurrence of this entity, skip it, as we only report duplicates.
       if (ECount <= 1)
         continue;
       LocationArray::iterator FI = DI->begin();
