@@ -245,12 +245,12 @@
 //===--------------------------------------------------------------------===//
 
 #include "clang/Lex/LexDiagnostic.h"
+#include "PreprocessorTracker.h"
 #include "clang/Lex/MacroArgs.h"
 #include "clang/Lex/PPCallbacks.h"
-#include "llvm/Support/raw_ostream.h"
-#include "llvm/Support/StringPool.h"
 #include "llvm/ADT/SmallSet.h"
-#include "PreprocessorTracker.h"
+#include "llvm/Support/StringPool.h"
+#include "llvm/Support/raw_ostream.h"
 
 namespace Modularize {
 
@@ -411,15 +411,15 @@ std::string getMacroExpandedString(clang::Preprocessor &PP,
     int ArgNo = (II && Args ? MI->getArgumentNum(II) : -1);
     if (ArgNo == -1) {
       // This isn't an argument, just add it.
-      if (II == NULL)
+      if (II == nullptr)
         Expanded += PP.getSpelling((*I)); // Not an identifier.
       else {
         // Token is for an identifier.
         std::string Name = II->getName().str();
         // Check for nexted macro references.
         clang::MacroInfo *MacroInfo = PP.getMacroInfo(II);
-        if (MacroInfo != NULL)
-          Expanded += getMacroExpandedString(PP, Name, MacroInfo, NULL);
+        if (MacroInfo)
+          Expanded += getMacroExpandedString(PP, Name, MacroInfo, nullptr);
         else
           Expanded += Name;
       }
@@ -441,14 +441,14 @@ std::string getMacroExpandedString(clang::Preprocessor &PP,
     for (unsigned ArgumentIndex = 0; ArgumentIndex < NumToks; ++ArgumentIndex) {
       const clang::Token &AT = ResultArgToks[ArgumentIndex];
       clang::IdentifierInfo *II = AT.getIdentifierInfo();
-      if (II == NULL)
+      if (II == nullptr)
         Expanded += PP.getSpelling(AT); // Not an identifier.
       else {
         // It's an identifier.  Check for further expansion.
         std::string Name = II->getName().str();
         clang::MacroInfo *MacroInfo = PP.getMacroInfo(II);
-        if (MacroInfo != NULL)
-          Expanded += getMacroExpandedString(PP, Name, MacroInfo, NULL);
+        if (MacroInfo)
+          Expanded += getMacroExpandedString(PP, Name, MacroInfo, nullptr);
         else
           Expanded += Name;
       }
@@ -483,15 +483,15 @@ std::string getExpandedString(clang::Preprocessor &PP,
     int ArgNo = (II && Args ? MI->getArgumentNum(II) : -1);
     if (ArgNo == -1) {
       // This isn't an argument, just add it.
-      if (II == NULL)
+      if (II == nullptr)
         Expanded += PP.getSpelling((*I)); // Not an identifier.
       else {
         // Token is for an identifier.
         std::string Name = II->getName().str();
         // Check for nexted macro references.
         clang::MacroInfo *MacroInfo = PP.getMacroInfo(II);
-        if (MacroInfo != NULL)
-          Expanded += getMacroExpandedString(PP, Name, MacroInfo, NULL);
+        if (MacroInfo)
+          Expanded += getMacroExpandedString(PP, Name, MacroInfo, nullptr);
         else
           Expanded += Name;
       }
@@ -513,14 +513,14 @@ std::string getExpandedString(clang::Preprocessor &PP,
     for (unsigned ArgumentIndex = 0; ArgumentIndex < NumToks; ++ArgumentIndex) {
       const clang::Token &AT = ResultArgToks[ArgumentIndex];
       clang::IdentifierInfo *II = AT.getIdentifierInfo();
-      if (II == NULL)
+      if (II == nullptr)
         Expanded += PP.getSpelling(AT); // Not an identifier.
       else {
         // It's an identifier.  Check for further expansion.
         std::string Name = II->getName().str();
         clang::MacroInfo *MacroInfo = PP.getMacroInfo(II);
-        if (MacroInfo != NULL)
-          Expanded += getMacroExpandedString(PP, Name, MacroInfo, NULL);
+        if (MacroInfo)
+          Expanded += getMacroExpandedString(PP, Name, MacroInfo, nullptr);
         else
           Expanded += Name;
       }
@@ -529,19 +529,12 @@ std::string getExpandedString(clang::Preprocessor &PP,
   return Expanded;
 }
 
-// We need some operator overloads for string handles.
-bool operator==(const StringHandle &H1, const StringHandle &H2) {
-  const char *S1 = (H1 ? *H1 : "");
-  const char *S2 = (H2 ? *H2 : "");
-  int Diff = strcmp(S1, S2);
-  return Diff == 0;
-}
-bool operator!=(const StringHandle &H1, const StringHandle &H2) {
-  const char *S1 = (H1 ? *H1 : "");
-  const char *S2 = (H2 ? *H2 : "");
-  int Diff = strcmp(S1, S2);
-  return Diff != 0;
-}
+// ConditionValueKind strings.
+const char *
+ConditionValueKindStrings[] = {
+  "(not evaluated)", "false", "true"
+};
+
 bool operator<(const StringHandle &H1, const StringHandle &H2) {
   const char *S1 = (H1 ? *H1 : "");
   const char *S2 = (H2 ? *H2 : "");
@@ -695,7 +688,7 @@ public:
         return &*I; // Found.
       }
     }
-    return NULL; // Not found.
+    return nullptr; // Not found.
   }
 
   // Add a macro expansion instance.
@@ -728,7 +721,7 @@ public:
 // for use in telling the user the nested include path to the header.
 class ConditionalExpansionInstance {
 public:
-  ConditionalExpansionInstance(bool ConditionValue, InclusionPathHandle H)
+  ConditionalExpansionInstance(clang::PPCallbacks::ConditionValueKind ConditionValue, InclusionPathHandle H)
       : ConditionValue(ConditionValue) {
     InclusionPathHandles.push_back(H);
   }
@@ -753,7 +746,7 @@ public:
   }
 
   // A flag representing the evaluated condition value.
-  bool ConditionValue;
+  clang::PPCallbacks::ConditionValueKind ConditionValue;
   // The header inclusion path handles for all the instances.
   std::vector<InclusionPathHandle> InclusionPathHandles;
 };
@@ -768,7 +761,8 @@ public:
 class ConditionalTracker {
 public:
   ConditionalTracker(clang::tok::PPKeywordKind DirectiveKind,
-                     bool ConditionValue, StringHandle ConditionUnexpanded,
+                     clang::PPCallbacks::ConditionValueKind ConditionValue,
+                     StringHandle ConditionUnexpanded,
                      InclusionPathHandle InclusionPathHandle)
       : DirectiveKind(DirectiveKind), ConditionUnexpanded(ConditionUnexpanded) {
     addConditionalExpansionInstance(ConditionValue, InclusionPathHandle);
@@ -777,7 +771,7 @@ public:
 
   // Find a matching condition expansion instance.
   ConditionalExpansionInstance *
-  findConditionalExpansionInstance(bool ConditionValue) {
+  findConditionalExpansionInstance(clang::PPCallbacks::ConditionValueKind ConditionValue) {
     for (std::vector<ConditionalExpansionInstance>::iterator
              I = ConditionalExpansionInstances.begin(),
              E = ConditionalExpansionInstances.end();
@@ -786,12 +780,12 @@ public:
         return &*I; // Found.
       }
     }
-    return NULL; // Not found.
+    return nullptr; // Not found.
   }
 
   // Add a conditional expansion instance.
   void
-  addConditionalExpansionInstance(bool ConditionValue,
+  addConditionalExpansionInstance(clang::PPCallbacks::ConditionValueKind ConditionValue,
                                   InclusionPathHandle InclusionPathHandle) {
     ConditionalExpansionInstances.push_back(
         ConditionalExpansionInstance(ConditionValue, InclusionPathHandle));
@@ -842,9 +836,9 @@ public:
   void Defined(const clang::Token &MacroNameTok,
                const clang::MacroDirective *MD, clang::SourceRange Range);
   void If(clang::SourceLocation Loc, clang::SourceRange ConditionRange,
-          bool ConditionResult);
+          clang::PPCallbacks::ConditionValueKind ConditionResult);
   void Elif(clang::SourceLocation Loc, clang::SourceRange ConditionRange,
-            bool ConditionResult, clang::SourceLocation IfLoc);
+            clang::PPCallbacks::ConditionValueKind ConditionResult, clang::SourceLocation IfLoc);
   void Ifdef(clang::SourceLocation Loc, const clang::Token &MacroNameTok,
              const clang::MacroDirective *MD);
   void Ifndef(clang::SourceLocation Loc, const clang::Token &MacroNameTok,
@@ -1119,7 +1113,7 @@ public:
           CondTracker.findMacroExpansionInstance(addString(MacroExpanded),
                                                  DefinitionKey);
       // If found, just add the inclusion path to the instance.
-      if (MacroInfo != NULL)
+      if (MacroInfo)
         MacroInfo->addInclusionPathHandle(InclusionPathHandle);
       else {
         // Otherwise add a new instance with the unique value.
@@ -1138,7 +1132,7 @@ public:
   addConditionalExpansionInstance(clang::Preprocessor &PP, HeaderHandle H,
                                   clang::SourceLocation InstanceLoc,
                                   clang::tok::PPKeywordKind DirectiveKind,
-                                  bool ConditionValue,
+                                  clang::PPCallbacks::ConditionValueKind ConditionValue,
                                   llvm::StringRef ConditionUnexpanded,
                                   InclusionPathHandle InclusionPathHandle) {
     // Ignore header guards, assuming the header guard is the only conditional.
@@ -1162,7 +1156,7 @@ public:
       ConditionalExpansionInstance *MacroInfo =
           CondTracker.findConditionalExpansionInstance(ConditionValue);
       // If found, just add the inclusion path to the instance.
-      if (MacroInfo != NULL)
+      if (MacroInfo)
         MacroInfo->addInclusionPathHandle(InclusionPathHandle);
       else {
         // Otherwise add a new instance with the unique value.
@@ -1264,7 +1258,7 @@ public:
            IMT != EMT; ++IMT) {
         ConditionalExpansionInstance &MacroInfo = *IMT;
         OS << "  '" << *CondTracker.ConditionUnexpanded << "' expanded to: '"
-           << (MacroInfo.ConditionValue ? "true" : "false")
+           << ConditionValueKindStrings[MacroInfo.ConditionValue]
            << "' with respect to these inclusion paths:\n";
         // Walk all the inclusion path hierarchies.
         for (std::vector<InclusionPathHandle>::iterator
@@ -1350,7 +1344,7 @@ void PreprocessorCallbacks::FileChanged(
   case ExitFile: {
     const clang::FileEntry *F =
         PP.getSourceManager().getFileEntryForID(PrevFID);
-    if (F != NULL)
+    if (F)
       PPTracker.handleHeaderExit(F->getName());
   } break;
   case SystemHeaderPragma:
@@ -1394,7 +1388,7 @@ void PreprocessorCallbacks::Defined(const clang::Token &MacroNameTok,
 
 void PreprocessorCallbacks::If(clang::SourceLocation Loc,
                                clang::SourceRange ConditionRange,
-                               bool ConditionResult) {
+                               clang::PPCallbacks::ConditionValueKind ConditionResult) {
   std::string Unexpanded(getSourceString(PP, ConditionRange));
   PPTracker.addConditionalExpansionInstance(
       PP, PPTracker.getCurrentHeaderHandle(), Loc, clang::tok::pp_if,
@@ -1403,7 +1397,7 @@ void PreprocessorCallbacks::If(clang::SourceLocation Loc,
 
 void PreprocessorCallbacks::Elif(clang::SourceLocation Loc,
                                  clang::SourceRange ConditionRange,
-                                 bool ConditionResult,
+                                 clang::PPCallbacks::ConditionValueKind ConditionResult,
                                  clang::SourceLocation IfLoc) {
   std::string Unexpanded(getSourceString(PP, ConditionRange));
   PPTracker.addConditionalExpansionInstance(
@@ -1414,7 +1408,8 @@ void PreprocessorCallbacks::Elif(clang::SourceLocation Loc,
 void PreprocessorCallbacks::Ifdef(clang::SourceLocation Loc,
                                   const clang::Token &MacroNameTok,
                                   const clang::MacroDirective *MD) {
-  bool IsDefined = (MD != 0);
+  clang::PPCallbacks::ConditionValueKind IsDefined =
+    (MD ? clang::PPCallbacks::CVK_True : clang::PPCallbacks::CVK_False );
   PPTracker.addConditionalExpansionInstance(
       PP, PPTracker.getCurrentHeaderHandle(), Loc, clang::tok::pp_ifdef,
       IsDefined, PP.getSpelling(MacroNameTok),
@@ -1424,7 +1419,8 @@ void PreprocessorCallbacks::Ifdef(clang::SourceLocation Loc,
 void PreprocessorCallbacks::Ifndef(clang::SourceLocation Loc,
                                    const clang::Token &MacroNameTok,
                                    const clang::MacroDirective *MD) {
-  bool IsNotDefined = (MD == 0);
+  clang::PPCallbacks::ConditionValueKind IsNotDefined =
+    (!MD ? clang::PPCallbacks::CVK_True : clang::PPCallbacks::CVK_False );
   PPTracker.addConditionalExpansionInstance(
       PP, PPTracker.getCurrentHeaderHandle(), Loc, clang::tok::pp_ifndef,
       IsNotDefined, PP.getSpelling(MacroNameTok),
